% DEST.M performs local Whittle estimation of the memory parameter d.
%   This program calls two other programs, ewhittle.m and whittle.m.
% 
% 
%               				Katsumi Shimotsu, September 2010
%_______________________________________________________________

clear;

d = 0.4;            % the value of d

u = randn(500,1);	% In this example, we generate 500 observations of an I(d) process.
x = fracdiff(u,-d); % Replace this part with your data.

n = length(x);
x2 = dmtrend(x);	% demeaned & detrended data

m = fix(n^0.6);		% m is the number of frequencies used in estimation.

options = optimset('fminbnd');

dw = fminbnd('whittle',-1,3,options,x,m);		% LW estimate
elw1 = felw2st(x,m,3,10);						% 2-step ELW 
elw2 = felw2st(x2,m,3,10);						% 2-step ELW w/ detrending
 
fprintf(1,'Number of observations     %7i \n', n);
fprintf(1,'Number of frequencies used %7i \n\n', m);
fprintf(1,'Estimate of d: LW estimator                       %7.5f  \n', dw);
fprintf(1,'Estimate of d: 2-step ELW estimator               %7.5f  \n', elw1);
fprintf(1,'Estimate of d: 2-step ELW estimator w/ detrending %7.5f  \n', elw2);
